==> openurp-edu-api4j-0.0.25-sources.jar: org/openurp/code/edu/model/ActivityType.java <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.code.edu.model;

import javax.persistence.Cacheable;
import javax.persistence.Entity;

import org.beangle.commons.entity.pojo.Code;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.openurp.code.industry;

/**
 * 教室占用情况
 *
 *
 * @since 2011-10-13
 */
@Entity(name = "org.openurp.code.edu.model.ActivityType")
@Cacheable
@Cache(region = "eams.base", usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@industry
public class ActivityType extends Code<Integer> {

  private static final long serialVersionUID = 790888757923982582L;

  /** 排课 */
  public static final int COURSE = 1;

  /** 排考 */
  public static final int EXAM = 2;

  public ActivityType() {
    super();
  }

  public ActivityType(Integer id) {
    super(id);
  }

}

==> openurp-edu-api4j-0.41.2-sources.jar: org/openurp/code/edu/model/ActivityType.java <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.code.edu.model;

import javax.persistence.Cacheable;
import javax.persistence.Entity;

import org.beangle.commons.entity.pojo.Code;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.openurp.code.industry;

/**
 * 教室占用情况
 *
 *
 * @since 2011-10-13
 */
@Entity(name = "org.openurp.code.edu.model.ActivityType")
@Cacheable
@Cache(region = "openurp.base", usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@industry
public class ActivityType extends Code<Integer> {

  private static final long serialVersionUID = 790888757923982582L;

  /** 排课 */
  public static final int Course = 1;

  /** 排考 */
  public static final int Exam = 2;

  public ActivityType() {
    super();
  }

  public ActivityType(Integer id) {
    super(id);
  }

}
